# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: zsearch_definitions/rpc.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zsearch_definitions import common_pb2 as zsearch__definitions_dot_common__pb2
from zsearch_definitions import anonstore_pb2 as zsearch__definitions_dot_anonstore__pb2
from zsearch_definitions import hoststore_pb2 as zsearch__definitions_dot_hoststore__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='zsearch_definitions/rpc.proto',
  package='zsearch',
  syntax='proto3',
  serialized_pb=_b('\n\x1dzsearch_definitions/rpc.proto\x12\x07zsearch\x1a zsearch_definitions/common.proto\x1a#zsearch_definitions/anonstore.proto\x1a#zsearch_definitions/hoststore.proto\"D\n\tMinScanId\x12\"\n\x03key\x18\x01 \x01(\x0b\x32\x15.zsearch.AnonymousKey\x12\x13\n\x0bmin_scan_id\x18\x02 \x01(\r\"t\n\x07\x43ommand\x12\x18\n\x10incremental_dump\x18\x01 \x01(\x08\x12(\n\x0cmin_scan_ids\x18\x02 \x03(\x0b\x32\x12.zsearch.MinScanId\x12\x10\n\x08\x66ilepath\x18\x03 \x01(\t\x12\x13\n\x0bmax_records\x18\x04 \x01(\r\"\x9d\x02\n\x18\x41nonymousStoreStatistics\x12\x15\n\rtotal_records\x18\x01 \x01(\x04\x12 \n\x18records_added_last_reset\x18\x02 \x01(\x04\x12\"\n\x1arecords_updated_last_reset\x18\x03 \x01(\x04\x12$\n\x1crecords_unchanged_last_reset\x18\x04 \x01(\x04\x12\x18\n\x10records_received\x18\x05 \x01(\x04\x12\x1e\n\x16records_in_redis_queue\x18\x06 \x01(\r\x12\x18\n\x10redis_queue_name\x18\x07 \x01(\t\x12\x12\n\nqueue_type\x18\x08 \x01(\t\x12\x16\n\x0eworker_threads\x18\t \x01(\r\"|\n\x0eStatisticsPair\x12\x0c\n\x04port\x18\x01 \x01(\r\x12\x10\n\x08protocol\x18\x02 \x01(\r\x12\x13\n\x0bsubprotocol\x18\x03 \x01(\r\x12\x35\n\nstatistics\x18\x04 \x01(\x0b\x32!.zsearch.AnonymousStoreStatistics\"p\n\x0fStoreStatistics\x12\x31\n\x06global\x18\x01 \x01(\x0b\x32!.zsearch.AnonymousStoreStatistics\x12*\n\tprotocols\x18\x02 \x03(\x0b\x32\x17.zsearch.StatisticsPair\"\xef\x02\n\x10ServerStatistics\x12H\n\x10store_statistics\x18\x01 \x03(\x0b\x32..zsearch.ServerStatistics.StoreStatisticsEntry\x12[\n\x1a\x61nonymous_store_statistics\x18\x02 \x03(\x0b\x32\x37.zsearch.ServerStatistics.AnonymousStoreStatisticsEntry\x1aP\n\x14StoreStatisticsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.zsearch.StoreStatistics:\x02\x38\x01\x1a\x62\n\x1d\x41nonymousStoreStatisticsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32!.zsearch.AnonymousStoreStatistics:\x02\x38\x01\"M\n\x0fPruneStatistics\x12\"\n\x03key\x18\x01 \x01(\x0b\x32\x15.zsearch.AnonymousKey\x12\x16\n\x0erecords_pruned\x18\x02 \x01(\x04\"\xe4\x01\n\x0c\x43ommandReply\x12\x33\n\x06status\x18\x01 \x01(\x0e\x32#.zsearch.CommandReply.CommandStatus\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12(\n\x05stats\x18\x03 \x01(\x0b\x32\x19.zsearch.ServerStatistics\x12\x32\n\x10prune_statistics\x18\x04 \x03(\x0b\x32\x18.zsearch.PruneStatistics\"2\n\rCommandStatus\x12\t\n\x05\x46\x41TAL\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\t\n\x05\x45RROR\x10\x02\"q\n\tHostQuery\x12\n\n\x02ip\x18\x01 \x01(\x07\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\r\x12\x10\n\x08protocol\x18\x04 \x01(\r\x12\x13\n\x0bsubprotocol\x18\x05 \x01(\r\x12\x13\n\x0bmax_records\x18\x06 \x01(\r\"\xb8\x02\n\x11HostQueryResponse\x12\x39\n\x06status\x18\x01 \x01(\x0e\x32).zsearch.HostQueryResponse.ResponseStatus\x12\n\n\x02ip\x18\x02 \x01(\x07\x12\x0e\n\x06\x64omain\x18\x03 \x01(\t\x12\x0c\n\x04port\x18\x04 \x01(\r\x12\x10\n\x08protocol\x18\x05 \x01(\r\x12\x13\n\x0bsubprotocol\x18\x06 \x01(\r\x12\x1f\n\x06record\x18\x07 \x01(\x0b\x32\x0f.zsearch.Record\x12 \n\x07records\x18\x08 \x03(\x0b\x32\x0f.zsearch.Record\x12\r\n\x05\x65rror\x18\t \x01(\t\"E\n\x0eResponseStatus\x12\x0c\n\x08RESERVED\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\r\n\tNO_RECORD\x10\x02\x12\t\n\x05\x45RROR\x10\x03\"\"\n\x0e\x41nonymousQuery\x12\x10\n\x08sha256fp\x18\x01 \x01(\x0c\"\x95\x02\n\x16\x41nonymousQueryResponse\x12\x10\n\x08sha256fp\x18\x01 \x01(\x0c\x12>\n\x06status\x18\x02 \x01(\x0e\x32..zsearch.AnonymousQueryResponse.ResponseStatus\x12(\n\x06record\x18\x03 \x01(\x0b\x32\x18.zsearch.AnonymousRecord\x12)\n\x07records\x18\x04 \x03(\x0b\x32\x18.zsearch.AnonymousRecord\x12\r\n\x05\x65rror\x18; \x01(\t\"E\n\x0eResponseStatus\x12\x0c\n\x08RESERVED\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\r\n\tNO_RECORD\x10\x02\x12\t\n\x05\x45RROR\x10\x03\"R\n\x0fUserDataRequest\x12\n\n\x02ip\x18\x01 \x01(\x07\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\x12#\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x15.zsearch.UserdataAtom\"\x9e\x01\n\x0eRootStoreQuery\x12\x38\n\x04type\x18\x01 \x01(\x0e\x32*.zsearch.RootStoreQuery.RootStoreQueryType\"R\n\x12RootStoreQueryType\x12\x0c\n\x08RESERVED\x10\x00\x12\x0b\n\x07MOZILLA\x10\x01\x12\r\n\tMICROSOFT\x10\x02\x12\t\n\x05\x41PPLE\x10\x03\x12\x07\n\x03\x41LL\x10\x04\"<\n\x0eRootStoreReply\x12*\n\x0c\x63\x65rtificates\x18\x01 \x03(\x0b\x32\x14.zsearch.Certificateb\x06proto3')
  ,
  dependencies=[zsearch__definitions_dot_common__pb2.DESCRIPTOR,zsearch__definitions_dot_anonstore__pb2.DESCRIPTOR,zsearch__definitions_dot_hoststore__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_COMMANDREPLY_COMMANDSTATUS = _descriptor.EnumDescriptor(
  name='CommandStatus',
  full_name='zsearch.CommandReply.CommandStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FATAL', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1494,
  serialized_end=1544,
)
_sym_db.RegisterEnumDescriptor(_COMMANDREPLY_COMMANDSTATUS)

_HOSTQUERYRESPONSE_RESPONSESTATUS = _descriptor.EnumDescriptor(
  name='ResponseStatus',
  full_name='zsearch.HostQueryResponse.ResponseStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_RECORD', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1905,
  serialized_end=1974,
)
_sym_db.RegisterEnumDescriptor(_HOSTQUERYRESPONSE_RESPONSESTATUS)

_ANONYMOUSQUERYRESPONSE_RESPONSESTATUS = _descriptor.EnumDescriptor(
  name='ResponseStatus',
  full_name='zsearch.AnonymousQueryResponse.ResponseStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_RECORD', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1905,
  serialized_end=1974,
)
_sym_db.RegisterEnumDescriptor(_ANONYMOUSQUERYRESPONSE_RESPONSESTATUS)

_ROOTSTOREQUERY_ROOTSTOREQUERYTYPE = _descriptor.EnumDescriptor(
  name='RootStoreQueryType',
  full_name='zsearch.RootStoreQuery.RootStoreQueryType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MOZILLA', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MICROSOFT', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='APPLE', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALL', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2453,
  serialized_end=2535,
)
_sym_db.RegisterEnumDescriptor(_ROOTSTOREQUERY_ROOTSTOREQUERYTYPE)


_MINSCANID = _descriptor.Descriptor(
  name='MinScanId',
  full_name='zsearch.MinScanId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='zsearch.MinScanId.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_scan_id', full_name='zsearch.MinScanId.min_scan_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=150,
  serialized_end=218,
)


_COMMAND = _descriptor.Descriptor(
  name='Command',
  full_name='zsearch.Command',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='incremental_dump', full_name='zsearch.Command.incremental_dump', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_scan_ids', full_name='zsearch.Command.min_scan_ids', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filepath', full_name='zsearch.Command.filepath', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_records', full_name='zsearch.Command.max_records', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=220,
  serialized_end=336,
)


_ANONYMOUSSTORESTATISTICS = _descriptor.Descriptor(
  name='AnonymousStoreStatistics',
  full_name='zsearch.AnonymousStoreStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_records', full_name='zsearch.AnonymousStoreStatistics.total_records', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='records_added_last_reset', full_name='zsearch.AnonymousStoreStatistics.records_added_last_reset', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='records_updated_last_reset', full_name='zsearch.AnonymousStoreStatistics.records_updated_last_reset', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='records_unchanged_last_reset', full_name='zsearch.AnonymousStoreStatistics.records_unchanged_last_reset', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='records_received', full_name='zsearch.AnonymousStoreStatistics.records_received', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='records_in_redis_queue', full_name='zsearch.AnonymousStoreStatistics.records_in_redis_queue', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='redis_queue_name', full_name='zsearch.AnonymousStoreStatistics.redis_queue_name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='queue_type', full_name='zsearch.AnonymousStoreStatistics.queue_type', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='worker_threads', full_name='zsearch.AnonymousStoreStatistics.worker_threads', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=339,
  serialized_end=624,
)


_STATISTICSPAIR = _descriptor.Descriptor(
  name='StatisticsPair',
  full_name='zsearch.StatisticsPair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='zsearch.StatisticsPair.port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='zsearch.StatisticsPair.protocol', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subprotocol', full_name='zsearch.StatisticsPair.subprotocol', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='statistics', full_name='zsearch.StatisticsPair.statistics', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=626,
  serialized_end=750,
)


_STORESTATISTICS = _descriptor.Descriptor(
  name='StoreStatistics',
  full_name='zsearch.StoreStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='global', full_name='zsearch.StoreStatistics.global', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='protocols', full_name='zsearch.StoreStatistics.protocols', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=752,
  serialized_end=864,
)


_SERVERSTATISTICS_STORESTATISTICSENTRY = _descriptor.Descriptor(
  name='StoreStatisticsEntry',
  full_name='zsearch.ServerStatistics.StoreStatisticsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='zsearch.ServerStatistics.StoreStatisticsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='zsearch.ServerStatistics.StoreStatisticsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1054,
  serialized_end=1134,
)

_SERVERSTATISTICS_ANONYMOUSSTORESTATISTICSENTRY = _descriptor.Descriptor(
  name='AnonymousStoreStatisticsEntry',
  full_name='zsearch.ServerStatistics.AnonymousStoreStatisticsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='zsearch.ServerStatistics.AnonymousStoreStatisticsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='zsearch.ServerStatistics.AnonymousStoreStatisticsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1136,
  serialized_end=1234,
)

_SERVERSTATISTICS = _descriptor.Descriptor(
  name='ServerStatistics',
  full_name='zsearch.ServerStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='store_statistics', full_name='zsearch.ServerStatistics.store_statistics', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='anonymous_store_statistics', full_name='zsearch.ServerStatistics.anonymous_store_statistics', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_SERVERSTATISTICS_STORESTATISTICSENTRY, _SERVERSTATISTICS_ANONYMOUSSTORESTATISTICSENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=867,
  serialized_end=1234,
)


_PRUNESTATISTICS = _descriptor.Descriptor(
  name='PruneStatistics',
  full_name='zsearch.PruneStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='zsearch.PruneStatistics.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='records_pruned', full_name='zsearch.PruneStatistics.records_pruned', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1236,
  serialized_end=1313,
)


_COMMANDREPLY = _descriptor.Descriptor(
  name='CommandReply',
  full_name='zsearch.CommandReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='zsearch.CommandReply.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='error', full_name='zsearch.CommandReply.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stats', full_name='zsearch.CommandReply.stats', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='prune_statistics', full_name='zsearch.CommandReply.prune_statistics', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _COMMANDREPLY_COMMANDSTATUS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1316,
  serialized_end=1544,
)


_HOSTQUERY = _descriptor.Descriptor(
  name='HostQuery',
  full_name='zsearch.HostQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip', full_name='zsearch.HostQuery.ip', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='domain', full_name='zsearch.HostQuery.domain', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='port', full_name='zsearch.HostQuery.port', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='zsearch.HostQuery.protocol', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subprotocol', full_name='zsearch.HostQuery.subprotocol', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_records', full_name='zsearch.HostQuery.max_records', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1546,
  serialized_end=1659,
)


_HOSTQUERYRESPONSE = _descriptor.Descriptor(
  name='HostQueryResponse',
  full_name='zsearch.HostQueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='zsearch.HostQueryResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ip', full_name='zsearch.HostQueryResponse.ip', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='domain', full_name='zsearch.HostQueryResponse.domain', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='port', full_name='zsearch.HostQueryResponse.port', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='zsearch.HostQueryResponse.protocol', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subprotocol', full_name='zsearch.HostQueryResponse.subprotocol', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='record', full_name='zsearch.HostQueryResponse.record', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='records', full_name='zsearch.HostQueryResponse.records', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='error', full_name='zsearch.HostQueryResponse.error', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _HOSTQUERYRESPONSE_RESPONSESTATUS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1662,
  serialized_end=1974,
)


_ANONYMOUSQUERY = _descriptor.Descriptor(
  name='AnonymousQuery',
  full_name='zsearch.AnonymousQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sha256fp', full_name='zsearch.AnonymousQuery.sha256fp', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1976,
  serialized_end=2010,
)


_ANONYMOUSQUERYRESPONSE = _descriptor.Descriptor(
  name='AnonymousQueryResponse',
  full_name='zsearch.AnonymousQueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sha256fp', full_name='zsearch.AnonymousQueryResponse.sha256fp', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='zsearch.AnonymousQueryResponse.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='record', full_name='zsearch.AnonymousQueryResponse.record', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='records', full_name='zsearch.AnonymousQueryResponse.records', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='error', full_name='zsearch.AnonymousQueryResponse.error', index=4,
      number=59, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ANONYMOUSQUERYRESPONSE_RESPONSESTATUS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2013,
  serialized_end=2290,
)


_USERDATAREQUEST = _descriptor.Descriptor(
  name='UserDataRequest',
  full_name='zsearch.UserDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip', full_name='zsearch.UserDataRequest.ip', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='domain', full_name='zsearch.UserDataRequest.domain', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='zsearch.UserDataRequest.data', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2292,
  serialized_end=2374,
)


_ROOTSTOREQUERY = _descriptor.Descriptor(
  name='RootStoreQuery',
  full_name='zsearch.RootStoreQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='zsearch.RootStoreQuery.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ROOTSTOREQUERY_ROOTSTOREQUERYTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2377,
  serialized_end=2535,
)


_ROOTSTOREREPLY = _descriptor.Descriptor(
  name='RootStoreReply',
  full_name='zsearch.RootStoreReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificates', full_name='zsearch.RootStoreReply.certificates', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2537,
  serialized_end=2597,
)

_MINSCANID.fields_by_name['key'].message_type = zsearch__definitions_dot_hoststore__pb2._ANONYMOUSKEY
_COMMAND.fields_by_name['min_scan_ids'].message_type = _MINSCANID
_STATISTICSPAIR.fields_by_name['statistics'].message_type = _ANONYMOUSSTORESTATISTICS
_STORESTATISTICS.fields_by_name['global'].message_type = _ANONYMOUSSTORESTATISTICS
_STORESTATISTICS.fields_by_name['protocols'].message_type = _STATISTICSPAIR
_SERVERSTATISTICS_STORESTATISTICSENTRY.fields_by_name['value'].message_type = _STORESTATISTICS
_SERVERSTATISTICS_STORESTATISTICSENTRY.containing_type = _SERVERSTATISTICS
_SERVERSTATISTICS_ANONYMOUSSTORESTATISTICSENTRY.fields_by_name['value'].message_type = _ANONYMOUSSTORESTATISTICS
_SERVERSTATISTICS_ANONYMOUSSTORESTATISTICSENTRY.containing_type = _SERVERSTATISTICS
_SERVERSTATISTICS.fields_by_name['store_statistics'].message_type = _SERVERSTATISTICS_STORESTATISTICSENTRY
_SERVERSTATISTICS.fields_by_name['anonymous_store_statistics'].message_type = _SERVERSTATISTICS_ANONYMOUSSTORESTATISTICSENTRY
_PRUNESTATISTICS.fields_by_name['key'].message_type = zsearch__definitions_dot_hoststore__pb2._ANONYMOUSKEY
_COMMANDREPLY.fields_by_name['status'].enum_type = _COMMANDREPLY_COMMANDSTATUS
_COMMANDREPLY.fields_by_name['stats'].message_type = _SERVERSTATISTICS
_COMMANDREPLY.fields_by_name['prune_statistics'].message_type = _PRUNESTATISTICS
_COMMANDREPLY_COMMANDSTATUS.containing_type = _COMMANDREPLY
_HOSTQUERYRESPONSE.fields_by_name['status'].enum_type = _HOSTQUERYRESPONSE_RESPONSESTATUS
_HOSTQUERYRESPONSE.fields_by_name['record'].message_type = zsearch__definitions_dot_hoststore__pb2._RECORD
_HOSTQUERYRESPONSE.fields_by_name['records'].message_type = zsearch__definitions_dot_hoststore__pb2._RECORD
_HOSTQUERYRESPONSE_RESPONSESTATUS.containing_type = _HOSTQUERYRESPONSE
_ANONYMOUSQUERYRESPONSE.fields_by_name['status'].enum_type = _ANONYMOUSQUERYRESPONSE_RESPONSESTATUS
_ANONYMOUSQUERYRESPONSE.fields_by_name['record'].message_type = zsearch__definitions_dot_anonstore__pb2._ANONYMOUSRECORD
_ANONYMOUSQUERYRESPONSE.fields_by_name['records'].message_type = zsearch__definitions_dot_anonstore__pb2._ANONYMOUSRECORD
_ANONYMOUSQUERYRESPONSE_RESPONSESTATUS.containing_type = _ANONYMOUSQUERYRESPONSE
_USERDATAREQUEST.fields_by_name['data'].message_type = zsearch__definitions_dot_common__pb2._USERDATAATOM
_ROOTSTOREQUERY.fields_by_name['type'].enum_type = _ROOTSTOREQUERY_ROOTSTOREQUERYTYPE
_ROOTSTOREQUERY_ROOTSTOREQUERYTYPE.containing_type = _ROOTSTOREQUERY
_ROOTSTOREREPLY.fields_by_name['certificates'].message_type = zsearch__definitions_dot_anonstore__pb2._CERTIFICATE
DESCRIPTOR.message_types_by_name['MinScanId'] = _MINSCANID
DESCRIPTOR.message_types_by_name['Command'] = _COMMAND
DESCRIPTOR.message_types_by_name['AnonymousStoreStatistics'] = _ANONYMOUSSTORESTATISTICS
DESCRIPTOR.message_types_by_name['StatisticsPair'] = _STATISTICSPAIR
DESCRIPTOR.message_types_by_name['StoreStatistics'] = _STORESTATISTICS
DESCRIPTOR.message_types_by_name['ServerStatistics'] = _SERVERSTATISTICS
DESCRIPTOR.message_types_by_name['PruneStatistics'] = _PRUNESTATISTICS
DESCRIPTOR.message_types_by_name['CommandReply'] = _COMMANDREPLY
DESCRIPTOR.message_types_by_name['HostQuery'] = _HOSTQUERY
DESCRIPTOR.message_types_by_name['HostQueryResponse'] = _HOSTQUERYRESPONSE
DESCRIPTOR.message_types_by_name['AnonymousQuery'] = _ANONYMOUSQUERY
DESCRIPTOR.message_types_by_name['AnonymousQueryResponse'] = _ANONYMOUSQUERYRESPONSE
DESCRIPTOR.message_types_by_name['UserDataRequest'] = _USERDATAREQUEST
DESCRIPTOR.message_types_by_name['RootStoreQuery'] = _ROOTSTOREQUERY
DESCRIPTOR.message_types_by_name['RootStoreReply'] = _ROOTSTOREREPLY

MinScanId = _reflection.GeneratedProtocolMessageType('MinScanId', (_message.Message,), dict(
  DESCRIPTOR = _MINSCANID,
  __module__ = 'zsearch_definitions.rpc_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.MinScanId)
  ))
_sym_db.RegisterMessage(MinScanId)

Command = _reflection.GeneratedProtocolMessageType('Command', (_message.Message,), dict(
  DESCRIPTOR = _COMMAND,
  __module__ = 'zsearch_definitions.rpc_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.Command)
  ))
_sym_db.RegisterMessage(Command)

AnonymousStoreStatistics = _reflection.GeneratedProtocolMessageType('AnonymousStoreStatistics', (_message.Message,), dict(
  DESCRIPTOR = _ANONYMOUSSTORESTATISTICS,
  __module__ = 'zsearch_definitions.rpc_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.AnonymousStoreStatistics)
  ))
_sym_db.RegisterMessage(AnonymousStoreStatistics)

StatisticsPair = _reflection.GeneratedProtocolMessageType('StatisticsPair', (_message.Message,), dict(
  DESCRIPTOR = _STATISTICSPAIR,
  __module__ = 'zsearch_definitions.rpc_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.StatisticsPair)
  ))
_sym_db.RegisterMessage(StatisticsPair)

StoreStatistics = _reflection.GeneratedProtocolMessageType('StoreStatistics', (_message.Message,), dict(
  DESCRIPTOR = _STORESTATISTICS,
  __module__ = 'zsearch_definitions.rpc_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.StoreStatistics)
  ))
_sym_db.RegisterMessage(StoreStatistics)

ServerStatistics = _reflection.GeneratedProtocolMessageType('ServerStatistics', (_message.Message,), dict(

  StoreStatisticsEntry = _reflection.GeneratedProtocolMessageType('StoreStatisticsEntry', (_message.Message,), dict(
    DESCRIPTOR = _SERVERSTATISTICS_STORESTATISTICSENTRY,
    __module__ = 'zsearch_definitions.rpc_pb2'
    # @@protoc_insertion_point(class_scope:zsearch.ServerStatistics.StoreStatisticsEntry)
    ))
  ,

  AnonymousStoreStatisticsEntry = _reflection.GeneratedProtocolMessageType('AnonymousStoreStatisticsEntry', (_message.Message,), dict(
    DESCRIPTOR = _SERVERSTATISTICS_ANONYMOUSSTORESTATISTICSENTRY,
    __module__ = 'zsearch_definitions.rpc_pb2'
    # @@protoc_insertion_point(class_scope:zsearch.ServerStatistics.AnonymousStoreStatisticsEntry)
    ))
  ,
  DESCRIPTOR = _SERVERSTATISTICS,
  __module__ = 'zsearch_definitions.rpc_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.ServerStatistics)
  ))
_sym_db.RegisterMessage(ServerStatistics)
_sym_db.RegisterMessage(ServerStatistics.StoreStatisticsEntry)
_sym_db.RegisterMessage(ServerStatistics.AnonymousStoreStatisticsEntry)

PruneStatistics = _reflection.GeneratedProtocolMessageType('PruneStatistics', (_message.Message,), dict(
  DESCRIPTOR = _PRUNESTATISTICS,
  __module__ = 'zsearch_definitions.rpc_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.PruneStatistics)
  ))
_sym_db.RegisterMessage(PruneStatistics)

CommandReply = _reflection.GeneratedProtocolMessageType('CommandReply', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDREPLY,
  __module__ = 'zsearch_definitions.rpc_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.CommandReply)
  ))
_sym_db.RegisterMessage(CommandReply)

HostQuery = _reflection.GeneratedProtocolMessageType('HostQuery', (_message.Message,), dict(
  DESCRIPTOR = _HOSTQUERY,
  __module__ = 'zsearch_definitions.rpc_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.HostQuery)
  ))
_sym_db.RegisterMessage(HostQuery)

HostQueryResponse = _reflection.GeneratedProtocolMessageType('HostQueryResponse', (_message.Message,), dict(
  DESCRIPTOR = _HOSTQUERYRESPONSE,
  __module__ = 'zsearch_definitions.rpc_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.HostQueryResponse)
  ))
_sym_db.RegisterMessage(HostQueryResponse)

AnonymousQuery = _reflection.GeneratedProtocolMessageType('AnonymousQuery', (_message.Message,), dict(
  DESCRIPTOR = _ANONYMOUSQUERY,
  __module__ = 'zsearch_definitions.rpc_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.AnonymousQuery)
  ))
_sym_db.RegisterMessage(AnonymousQuery)

AnonymousQueryResponse = _reflection.GeneratedProtocolMessageType('AnonymousQueryResponse', (_message.Message,), dict(
  DESCRIPTOR = _ANONYMOUSQUERYRESPONSE,
  __module__ = 'zsearch_definitions.rpc_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.AnonymousQueryResponse)
  ))
_sym_db.RegisterMessage(AnonymousQueryResponse)

UserDataRequest = _reflection.GeneratedProtocolMessageType('UserDataRequest', (_message.Message,), dict(
  DESCRIPTOR = _USERDATAREQUEST,
  __module__ = 'zsearch_definitions.rpc_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.UserDataRequest)
  ))
_sym_db.RegisterMessage(UserDataRequest)

RootStoreQuery = _reflection.GeneratedProtocolMessageType('RootStoreQuery', (_message.Message,), dict(
  DESCRIPTOR = _ROOTSTOREQUERY,
  __module__ = 'zsearch_definitions.rpc_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.RootStoreQuery)
  ))
_sym_db.RegisterMessage(RootStoreQuery)

RootStoreReply = _reflection.GeneratedProtocolMessageType('RootStoreReply', (_message.Message,), dict(
  DESCRIPTOR = _ROOTSTOREREPLY,
  __module__ = 'zsearch_definitions.rpc_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.RootStoreReply)
  ))
_sym_db.RegisterMessage(RootStoreReply)


_SERVERSTATISTICS_STORESTATISTICSENTRY.has_options = True
_SERVERSTATISTICS_STORESTATISTICSENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_SERVERSTATISTICS_ANONYMOUSSTORESTATISTICSENTRY.has_options = True
_SERVERSTATISTICS_ANONYMOUSSTORESTATISTICSENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
import abc
from grpc.early_adopter import implementations
from grpc.framework.alpha import utilities
# @@protoc_insertion_point(module_scope)
